.wp-block-quote {
  border-right: 0.25em solid currentColor;
  margin: 0 0 1.75em 0;
  padding-right: 1em;
}
.wp-block-quote cite,
.wp-block-quote footer {
  color: currentColor;
  font-size: 0.8125em;
  position: relative;
  font-style: normal;
}
.wp-block-quote:where(.has-text-align-right) {
  border-right: none;
  border-left: 0.25em solid currentColor;
  padding-right: 0;
  padding-left: 1em;
}
.wp-block-quote:where(.has-text-align-center) {
  border: none;
  padding-right: 0;
}
.wp-block-quote:where(.is-style-plain), .wp-block-quote.is-style-large, .wp-block-quote.is-large {
  border: none;
}