/**
 * Typography
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
 * Breakpoints & Media Queries
 */
/**
*  Converts a hex value into the rgb equivalent.
*
* @param {string} hex - the hexadecimal value to convert
* @return {string} comma separated rgb values
*/
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Breakpoint mixins
 */
/**
 * Focus styles.
 */
/**
 * Standard focus rings for the WordPress Design System.
 *
 * Apply `outset-ring__focus` inside the relevant pseudo-class at the call site,
 * e.g. `&:focus { @include outset-ring__focus(); }`.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
/**
 * Creates a checkerboard pattern background to indicate transparency.
 * @param {String} $size - The size of the squares in the checkerboard pattern. Default is 12px.
 */
:root {
  --wp-block-synced-color: #7a00df;
  --wp-block-synced-color--rgb: 122, 0, 223;
  --wp-bound-block-color: var(--wp-block-synced-color);
  --wp-editor-canvas-background: #ddd;
  --wp-admin-theme-color: #007cba;
  --wp-admin-theme-color--rgb: 0, 124, 186;
  --wp-admin-theme-color-darker-10: rgb(0, 107, 160.5);
  --wp-admin-theme-color-darker-10--rgb: 0, 107, 160.5;
  --wp-admin-theme-color-darker-20: #005a87;
  --wp-admin-theme-color-darker-20--rgb: 0, 90, 135;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  :root {
    --wp-admin-border-width-focus: 1.5px;
  }
}

.commands-command-menu {
  margin: auto;
  position: relative;
  top: calc(5% + 64px);
}
@media (min-width: 600px) {
  .commands-command-menu {
    top: calc(10% + 64px);
  }
}
.commands-command-menu .components-modal__content {
  margin: 0;
  padding: 0;
  overflow: hidden;
}

.commands-command-menu__overlay {
  display: block;
  align-items: start;
}

.commands-command-menu__header {
  display: flex;
  align-items: center;
  gap: 8px;
  padding: 0 16px;
}
.commands-command-menu__header .components-button {
  height: 56px;
  width: 56px;
  border: 1px solid #949494;
  border-right: 0;
  justify-content: center;
  border-radius: 2px 0 0 2px;
}
.commands-command-menu__header .components-button + [cmdk-input] {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.commands-command-menu__header-search-icon:dir(ltr) {
  transform: scaleX(-1);
}

.commands-command-menu__container {
  will-change: transform;
}
.commands-command-menu__container [cmdk-input] {
  border: none;
  width: 100%;
  padding: 12px 4px;
  outline: none;
  color: #1e1e1e;
  margin: 0;
  font-size: 15px;
  line-height: 24px;
  border-radius: 0;
}
.commands-command-menu__container [cmdk-input]::-moz-placeholder {
  color: #757575;
}
.commands-command-menu__container [cmdk-input]::placeholder {
  color: #757575;
}
.commands-command-menu__container [cmdk-input]:focus {
  box-shadow: none;
  outline: none;
}
.commands-command-menu__container [cmdk-item] {
  cursor: var(--wpds-cursor-control, pointer);
  display: flex;
  align-items: center;
  padding: 4px 0;
  color: #1e1e1e;
  font-size: 13px;
}
.commands-command-menu__container [cmdk-item][aria-disabled=true] {
  color: #949494;
  cursor: not-allowed;
}
.commands-command-menu__container [cmdk-item] svg {
  fill: #1e1e1e;
}
.commands-command-menu__container [cmdk-item] > div {
  border-radius: 2px;
  min-height: 32px;
  padding: 4px;
  padding-left: 40px;
  padding-right: 16px;
}
.commands-command-menu__container [cmdk-item][aria-selected=true] > div, .commands-command-menu__container [cmdk-item]:active > div {
  background: var(--wp-admin-theme-color);
  color: #fff;
}
.commands-command-menu__container [cmdk-item][aria-selected=true] > div svg, .commands-command-menu__container [cmdk-item]:active > div svg {
  fill: #fff;
}
.commands-command-menu__container [cmdk-item] > .has-icon {
  padding-left: 8px;
}
.commands-command-menu__container [cmdk-group]:has([cmdk-group-items]:empty) {
  display: none;
}
.commands-command-menu__container [cmdk-root] > [cmdk-list] {
  max-height: min(328px, 70vh - 48px);
  overflow: auto;
  scroll-padding-top: 8px;
  scroll-padding-bottom: 8px;
}
.commands-command-menu__container [cmdk-root] > [cmdk-list]:has([cmdk-group-items]:not(:empty)), .commands-command-menu__container [cmdk-root] > [cmdk-list]:has([cmdk-empty]) {
  border-top: 1px solid #ddd;
}
.commands-command-menu__container [cmdk-root] > [cmdk-list] [cmdk-list-sizer] > [cmdk-group] > [cmdk-group-items]:not(:empty) {
  padding: 0 8px 4px;
}
.commands-command-menu__container [cmdk-root] > [cmdk-list] [cmdk-group-heading] {
  margin-top: 8px;
  padding: 8px 16px;
  line-height: 16px;
  font-size: 11px;
  font-weight: var(--wpds-typography-font-weight-emphasis, 600);
  text-transform: uppercase;
  color: #1e1e1e;
}
.commands-command-menu__container [cmdk-empty] {
  display: flex;
  align-items: center;
  justify-content: center;
  white-space: pre-wrap;
  color: #1e1e1e;
  padding: 8px 0 32px;
}
.commands-command-menu__container [cmdk-loading] {
  padding: 16px;
}
.commands-command-menu__container [cmdk-list-sizer] {
  position: relative;
}

.commands-command-menu__item-label {
  display: inline-block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  flex: 1;
  min-width: 0;
}

.commands-command-menu__item-category {
  flex: 0 0 auto;
  margin-left: auto;
  padding-left: 24px;
  color: #757575;
  font-size: 13px;
  line-height: 1.4;
  text-align: right;
}
[aria-selected=true] .commands-command-menu__item-category, [cmdk-item]:active .commands-command-menu__item-category {
  color: rgba(255, 255, 255, 0.8);
}

.commands-command-menu__item mark {
  color: inherit;
  background: unset;
  font-weight: var(--wpds-typography-font-weight-emphasis, 600);
}