/**
 * Editor and frontend styles for the Icon Block.
 */
/* Icon Block styles. */
.wp-block-icon {
  line-height: 0;
}
.wp-block-icon.aligncenter {
  display: flex;
  justify-content: center;
}
.wp-block-icon svg {
  box-sizing: border-box;
  fill: currentColor;
}
.wp-block-icon svg.is-flip-horizontal {
  transform: scaleX(-1);
}
.wp-block-icon svg.is-flip-vertical {
  transform: scaleY(-1);
}
.wp-block-icon svg.is-flip-horizontal.is-flip-vertical {
  transform: scaleX(-1) scaleY(-1);
}

:where(.wp-block-icon) svg {
  width: 100%;
  height: 100%;
}