@use "../_admin.scss" with (
  $scheme-name: "sunrise",
  $base-color: #8a312d,
  $highlight-color: #ad631e,
  $notification-color: #ccaf0b,
  $menu-highlight-text: #fff,
  $menu-highlight-icon: #fff,
  $menu-bubble-text: #1e1e1e,
  $menu-submenu-focus-text: #fff
);
