<?php
/**
 * Title: No results
 * Slug: twentytwentyfour/hidden-no-results
 * Inserter: no
 *
 * @package WordPress
 * @subpackage Twenty_Twenty_Four
 * @since Twenty Twenty-Four 1.0
 */

?>

<!-- wp:paragraph -->
<p><?php echo esc_html_x( 'No posts were found.', 'Message explaining that there are no results returned from a search', 'twentytwentyfour' ); ?></p>
<!-- /wp:paragraph -->
