<?php
/**
 * Pages loader - Auto-generated by build process.
 * Do not edit this file manually.
 *
 * @package wp
 */

foreach ( [
	__DIR__ . '/pages/font-library/page.php',
	__DIR__ . '/pages/font-library/page-wp-admin.php',
	__DIR__ . '/pages/options-connectors/page.php',
	__DIR__ . '/pages/options-connectors/page-wp-admin.php',
] as $file ) {
	if ( file_exists( $file ) ) {
		require_once $file;
	}
}
