.wp-block-breadcrumbs {
  box-sizing: border-box;
}
.wp-block-breadcrumbs ol {
  list-style: none;
  margin: 0;
  padding: 0;
  display: flex;
  flex-wrap: wrap;
  align-items: center;
}
.wp-block-breadcrumbs li {
  margin: 0;
  padding: 0;
  display: flex;
  align-items: center;
}
.wp-block-breadcrumbs li:not(:last-child)::after {
  content: var(--separator, "/")/"";
  margin: 0 0.5em;
  opacity: 0.7;
}
.wp-block-breadcrumbs span {
  color: inherit;
}