/**
 * Breakpoints & Media Queries
 */
/**
 * Colors
 */
/**
 * Typography
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
*  Converts a hex value into the rgb equivalent.
*
* @param {string} hex - the hexadecimal value to convert
* @return {string} comma separated rgb values
*/
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Breakpoint mixins
 */
/**
 * Focus styles.
 */
/**
 * Standard focus rings for the WordPress Design System.
 *
 * Apply `outset-ring__focus` inside the relevant pseudo-class at the call site,
 * e.g. `&:focus { @include outset-ring__focus(); }`.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
/**
 * Creates a checkerboard pattern background to indicate transparency.
 * @param {String} $size - The size of the squares in the checkerboard pattern. Default is 12px.
 */
:root :where(figure.wp-block-gallery) {
  display: block;
}
:root :where(figure.wp-block-gallery) > .blocks-gallery-caption {
  flex: 0 0 100%;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder.is-appender .components-placeholder__label {
  display: none;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder.is-appender .block-editor-media-placeholder__button {
  margin-bottom: 0;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder {
  margin: 0;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder .components-placeholder__label {
  display: flex;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder figcaption {
  z-index: 2;
}
:root :where(figure.wp-block-gallery) .components-spinner {
  position: absolute;
  top: 50%;
  left: 50%;
  margin-top: -9px;
  margin-left: -9px;
}

/**
 * Gallery inspector controls settings.
 */
.gallery-settings-buttons .components-button:first-child {
  margin-right: 8px;
}

/**
 * Deprecated css past this point. This can be removed once all galleries are migrated
 * to V2.
 */
.blocks-gallery-item figure:not(.is-selected):focus,
.blocks-gallery-item img:focus {
  outline: none;
}
.blocks-gallery-item figure.is-selected::before {
  box-shadow: 0 0 0 1px #fff inset, 0 0 0 3px var(--wp-admin-theme-color) inset;
  content: "";
  outline: 2px solid transparent;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1;
  pointer-events: none;
}
.blocks-gallery-item figure.is-transient img {
  opacity: 0.3;
}
.blocks-gallery-item .block-editor-media-placeholder {
  margin: 0;
  height: 100%;
}
.blocks-gallery-item .block-editor-media-placeholder .components-placeholder__label {
  display: flex;
}

.wp-block-gallery ul.blocks-gallery-grid {
  padding: 0;
  margin: 0;
}

@media (min-width: 600px) {
  .wp-block-update-gallery-modal {
    max-width: 480px;
  }
}

.wp-block-update-gallery-modal-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 12px;
}

.wp-block-gallery__source-settings {
  grid-column: 1/-1;
  display: flex;
  flex-direction: column;
  gap: 8px;
}
.wp-block-gallery__source-settings .wp-block-gallery__source-description {
  margin: 0;
  color: #757575;
  font-size: 12px;
}
.wp-block-gallery__source-settings .components-button {
  justify-content: center;
  width: 100%;
}

.wp-block-gallery__source-notice {
  grid-column: 1/-1;
  margin: 0;
}