@charset "UTF-8";
/* -------------------------------------------
 *  Autogenerated by ⛋ Terrazzo. DO NOT EDIT!
 * ------------------------------------------- */
:root {
  /* Buttons and other elements nested inside controls. */
  --wpds-border-radius-xs: 1px;
  /* Standalone buttons, inputs, and compact controls. */
  --wpds-border-radius-sm: 2px;
  /* Menus, popovers, and other small portaled overlays. */
  --wpds-border-radius-md: 4px;
  /* Cards, dialogs, notices, and other larger content containers. */
  --wpds-border-radius-lg: 8px;
  /* Page and app shell surfaces. */
  --wpds-border-radius-xl: 12px;
  /* Extra small width */
  --wpds-border-width-xs: 1px;
  /* Small width */
  --wpds-border-width-sm: 2px;
  /* Medium width */
  --wpds-border-width-md: 4px;
  /* Large width */
  --wpds-border-width-lg: 8px;
  /* Border width for focus ring */
  --wpds-border-width-focus: 2px;
  /* Background color for surfaces with normal emphasis. */
  --wpds-color-background-surface-neutral: #fcfcfc;
  /* Background color for surfaces with strong emphasis. */
  --wpds-color-background-surface-neutral-strong: #fff;
  /* Background color for surfaces with weak emphasis. */
  --wpds-color-background-surface-neutral-weak: #f4f4f4;
  /* Background color for surfaces with brand tone and normal emphasis. */
  --wpds-color-background-surface-brand: #ecf0fa;
  /* Background color for surfaces with success tone and normal emphasis. */
  --wpds-color-background-surface-success: #c6f7cd;
  /* Background color for surfaces with success tone and weak emphasis. */
  --wpds-color-background-surface-success-weak: #ebffed;
  /* Background color for surfaces with info tone and normal emphasis. */
  --wpds-color-background-surface-info: #deebfa;
  /* Background color for surfaces with info tone and weak emphasis. */
  --wpds-color-background-surface-info-weak: #f3f9ff;
  /* Background color for surfaces with warning tone and normal emphasis. */
  --wpds-color-background-surface-warning: #fde6be;
  /* Background color for surfaces with warning tone and weak emphasis. */
  --wpds-color-background-surface-warning-weak: #fff7e1;
  /* Background color for surfaces with caution tone and normal emphasis. */
  --wpds-color-background-surface-caution: #fee995;
  /* Background color for surfaces with caution tone and weak emphasis. */
  --wpds-color-background-surface-caution-weak: #fff9ca;
  /* Background color for surfaces with error tone and normal emphasis. */
  --wpds-color-background-surface-error: #f6e6e3;
  /* Background color for surfaces with error tone and weak emphasis. */
  --wpds-color-background-surface-error-weak: #fff6f5;
  /* Background color for interactive elements with neutral tone and strong emphasis. */
  --wpds-color-background-interactive-neutral-strong: #2d2d2d;
  /* Background color for interactive elements with neutral tone and strong emphasis that are hovered, focused, or active. */
  --wpds-color-background-interactive-neutral-strong-active: #1e1e1e;
  /* Background color for interactive elements with neutral tone and strong emphasis, in their disabled state. */
  --wpds-color-background-interactive-neutral-strong-disabled: #e6e6e6;
  /* Background color for interactive elements with neutral tone and weak emphasis. */
  --wpds-color-background-interactive-neutral-weak: #0000;
  /* Background color for interactive elements with neutral tone and weak emphasis that are hovered, focused, or active. */
  --wpds-color-background-interactive-neutral-weak-active: #ededed;
  /* Background color for interactive elements with neutral tone and weak emphasis, in their disabled state. */
  --wpds-color-background-interactive-neutral-weak-disabled: #0000;
  /* Background color for interactive elements with brand tone and strong emphasis. */
  --wpds-color-background-interactive-brand-strong: #3858e9;
  /* Background color for interactive elements with brand tone and strong emphasis that are hovered, focused, or active. */
  --wpds-color-background-interactive-brand-strong-active: #2e49d9;
  /* Background color for interactive elements with brand tone and strong emphasis, in their disabled state. */
  --wpds-color-background-interactive-brand-strong-disabled: #e6e6e6;
  /* Background color for interactive elements with brand tone and weak emphasis. */
  --wpds-color-background-interactive-brand-weak: #0000;
  /* Background color for interactive elements with brand tone and weak emphasis that are hovered, focused, or active. */
  --wpds-color-background-interactive-brand-weak-active: #e6eaf4;
  /* Background color for interactive elements with brand tone and weak emphasis, in their disabled state. */
  --wpds-color-background-interactive-brand-weak-disabled: #0000;
  /* Background color for interactive elements with error tone and normal emphasis. */
  --wpds-color-background-interactive-error: #0000;
  /* Background color for interactive elements with error tone and normal emphasis that are hovered, focused, or active. */
  --wpds-color-background-interactive-error-active: #fff6f5;
  /* Background color for interactive elements with error tone and normal emphasis, in their disabled state. */
  --wpds-color-background-interactive-error-disabled: #0000;
  /* Background color for interactive elements with error tone and strong emphasis. */
  --wpds-color-background-interactive-error-strong: #cc1818;
  /* Background color for interactive elements with error tone and strong emphasis that are hovered, focused, or active. */
  --wpds-color-background-interactive-error-strong-active: #b90000;
  /* Background color for interactive elements with error tone and strong emphasis, in their disabled state. */
  --wpds-color-background-interactive-error-strong-disabled: #e6e6e6;
  /* Background color for interactive elements with error tone and weak emphasis. */
  --wpds-color-background-interactive-error-weak: #0000;
  /* Background color for interactive elements with error tone and weak emphasis that are hovered, focused, or active. */
  --wpds-color-background-interactive-error-weak-active: #f6e6e3;
  /* Background color for interactive elements with error tone and weak emphasis, in their disabled state. */
  --wpds-color-background-interactive-error-weak-disabled: #0000;
  /* Background color for tracks with a neutral tone and weak emphasis (eg. scrollbar track). */
  --wpds-color-background-track-neutral-weak: #f0f0f0;
  /* Background color for tracks with a neutral tone and normal emphasis (eg. slider or progressbar track). */
  --wpds-color-background-track-neutral: #dbdbdb;
  /* Background color for thumbs with a neutral tone and weak emphasis (eg. scrollbar thumb). */
  --wpds-color-background-thumb-neutral-weak: #8d8d8d;
  /* Background color for thumbs with a neutral tone and weak emphasis (eg. scrollbar thumb) that are hovered, focused, or active. */
  --wpds-color-background-thumb-neutral-weak-active: #6e6e6e;
  /* Background color for thumbs with a brand tone and normal emphasis (eg. slider thumb and filled track). */
  --wpds-color-background-thumb-brand: #3858e9;
  /* Background color for thumbs with a brand tone and normal emphasis (eg. slider thumb and filled track) that are hovered, focused, or active. */
  --wpds-color-background-thumb-brand-active: #3858e9;
  /* Background color for thumbs with a brand tone and normal emphasis (eg. slider thumb and filled track), in their disabled state. */
  --wpds-color-background-thumb-brand-disabled: #dbdbdb;
  /* Background color for thumbs with a neutral tone and weak emphasis (eg. scrollbar thumb), in their disabled state. */
  --wpds-color-background-thumb-neutral-weak-disabled: #dbdbdb;
  /* Foreground color for content like text with normal emphasis. */
  --wpds-color-foreground-content-neutral: #1e1e1e;
  /* Foreground color for content like text with weak emphasis. */
  --wpds-color-foreground-content-neutral-weak: #707070;
  /* Foreground color for content like text with success tone and normal emphasis. */
  --wpds-color-foreground-content-success: #002900;
  /* Foreground color for content like text with success tone and weak emphasis. */
  --wpds-color-foreground-content-success-weak: #008030;
  /* Foreground color for content like text with info tone and normal emphasis. */
  --wpds-color-foreground-content-info: #001b4f;
  /* Foreground color for content like text with info tone and weak emphasis. */
  --wpds-color-foreground-content-info-weak: #006bd7;
  /* Foreground color for content like text with warning tone and normal emphasis. */
  --wpds-color-foreground-content-warning: #2e1900;
  /* Foreground color for content like text with warning tone and weak emphasis. */
  --wpds-color-foreground-content-warning-weak: #926300;
  /* Foreground color for content like text with caution tone and normal emphasis. */
  --wpds-color-foreground-content-caution: #281d00;
  /* Foreground color for content like text with caution tone and weak emphasis. */
  --wpds-color-foreground-content-caution-weak: #826a00;
  /* Foreground color for content like text with error tone and normal emphasis. */
  --wpds-color-foreground-content-error: #470000;
  /* Foreground color for content like text with error tone and weak emphasis. */
  --wpds-color-foreground-content-error-weak: #cc1818;
  /* Foreground color for interactive elements with neutral tone and normal emphasis. */
  --wpds-color-foreground-interactive-neutral: #1e1e1e;
  /* Foreground color for interactive elements with neutral tone and normal emphasis that are hovered, focused, or active. */
  --wpds-color-foreground-interactive-neutral-active: #1e1e1e;
  /* Foreground color for interactive elements with neutral tone and normal emphasis, in their disabled state. */
  --wpds-color-foreground-interactive-neutral-disabled: #8d8d8d;
  /* Foreground color for interactive elements with neutral tone and strong emphasis. */
  --wpds-color-foreground-interactive-neutral-strong: #f0f0f0;
  /* Foreground color for interactive elements with neutral tone and strong emphasis that are hovered, focused, or active. */
  --wpds-color-foreground-interactive-neutral-strong-active: #f0f0f0;
  /* Foreground color for interactive elements with neutral tone and strong emphasis, in their disabled state. */
  --wpds-color-foreground-interactive-neutral-strong-disabled: #8d8d8d;
  /* Foreground color for interactive elements with neutral tone and weak emphasis. */
  --wpds-color-foreground-interactive-neutral-weak: #707070;
  /* Foreground color for interactive elements with neutral tone and weak emphasis that are hovered, focused, or active. */
  --wpds-color-foreground-interactive-neutral-weak-active: #1e1e1e;
  /* Foreground color for interactive elements with neutral tone and weak emphasis, in their disabled state. */
  --wpds-color-foreground-interactive-neutral-weak-disabled: #8d8d8d;
  /* Foreground color for interactive elements with brand tone and normal emphasis. */
  --wpds-color-foreground-interactive-brand: #3858e9;
  /* Foreground color for interactive elements with brand tone and normal emphasis that are hovered, focused, or active. */
  --wpds-color-foreground-interactive-brand-active: #0b0070;
  /* Foreground color for interactive elements with brand tone and normal emphasis, in their disabled state. */
  --wpds-color-foreground-interactive-brand-disabled: #8d8d8d;
  /* Foreground color for interactive elements with brand tone and strong emphasis. */
  --wpds-color-foreground-interactive-brand-strong: #eff0f2;
  /* Foreground color for interactive elements with brand tone and strong emphasis that are hovered, focused, or active. */
  --wpds-color-foreground-interactive-brand-strong-active: #eff0f2;
  /* Foreground color for interactive elements with brand tone and strong emphasis, in their disabled state. */
  --wpds-color-foreground-interactive-brand-strong-disabled: #8d8d8d;
  /* Foreground color for interactive elements with error tone and normal emphasis. */
  --wpds-color-foreground-interactive-error: #cc1818;
  /* Foreground color for interactive elements with error tone and normal emphasis that are hovered, focused, or active. */
  --wpds-color-foreground-interactive-error-active: #470000;
  /* Foreground color for interactive elements with error tone and normal emphasis, in their disabled state. */
  --wpds-color-foreground-interactive-error-disabled: #8d8d8d;
  /* Foreground color for interactive elements with error tone and strong emphasis. */
  --wpds-color-foreground-interactive-error-strong: #f2efef;
  /* Foreground color for interactive elements with error tone and strong emphasis that are hovered, focused, or active. */
  --wpds-color-foreground-interactive-error-strong-active: #f2efef;
  /* Foreground color for interactive elements with error tone and strong emphasis, in their disabled state. */
  --wpds-color-foreground-interactive-error-strong-disabled: #8d8d8d;
  /* Decorative stroke color used to define neutrally-toned surface boundaries with normal emphasis. */
  --wpds-color-stroke-surface-neutral: #dbdbdb;
  /* Decorative stroke color used to define neutrally-toned surface boundaries with weak emphasis. */
  --wpds-color-stroke-surface-neutral-weak: #f0f0f0;
  /* Decorative stroke color used to define neutrally-toned surface boundaries with strong emphasis. */
  --wpds-color-stroke-surface-neutral-strong: #8d8d8d;
  /* Decorative stroke color used to define brand-toned surface boundaries with normal emphasis. */
  --wpds-color-stroke-surface-brand: #b0bbd6;
  /* Decorative stroke color used to define brand-toned surface boundaries with strong emphasis. */
  --wpds-color-stroke-surface-brand-strong: #3858e9;
  /* Decorative stroke color used to define success-toned surface boundaries with normal emphasis. */
  --wpds-color-stroke-surface-success: #94d29e;
  /* Decorative stroke color used to define success-toned surface boundaries with strong emphasis. */
  --wpds-color-stroke-surface-success-strong: #008030;
  /* Decorative stroke color used to define info-toned surface boundaries with normal emphasis. */
  --wpds-color-stroke-surface-info: #a9c6e7;
  /* Decorative stroke color used to define info-toned surface boundaries with strong emphasis. */
  --wpds-color-stroke-surface-info-strong: #006bd7;
  /* Decorative stroke color used to define warning-toned surface boundaries with normal emphasis. */
  --wpds-color-stroke-surface-warning: #e1bc7c;
  /* Decorative stroke color used to define warning-toned surface boundaries with strong emphasis. */
  --wpds-color-stroke-surface-warning-strong: #926300;
  /* Decorative stroke color used to define caution-toned surface boundaries with normal emphasis. */
  --wpds-color-stroke-surface-caution: #cfc28d;
  /* Decorative stroke color used to define caution-toned surface boundaries with strong emphasis. */
  --wpds-color-stroke-surface-caution-strong: #826a00;
  /* Decorative stroke color used to define error-toned surface boundaries with normal emphasis. */
  --wpds-color-stroke-surface-error: #dab1aa;
  /* Decorative stroke color used to define error-toned surface boundaries with strong emphasis. */
  --wpds-color-stroke-surface-error-strong: #cc1818;
  /* Accessible stroke color used for interactive neutrally-toned elements with normal emphasis. */
  --wpds-color-stroke-interactive-neutral: #8d8d8d;
  /* Accessible stroke color used for interactive neutrally-toned elements with normal emphasis that are hovered, focused, or active. */
  --wpds-color-stroke-interactive-neutral-active: #6e6e6e;
  /* Accessible stroke color used for interactive neutrally-toned elements with normal emphasis, in their disabled state. */
  --wpds-color-stroke-interactive-neutral-disabled: #dbdbdb;
  /* Accessible stroke color used for interactive neutrally-toned elements with strong emphasis. */
  --wpds-color-stroke-interactive-neutral-strong: #6e6e6e;
  /* Accessible stroke color used for interactive brand-toned elements with normal emphasis. */
  --wpds-color-stroke-interactive-brand: #3858e9;
  /* Accessible stroke color used for interactive brand-toned elements with normal emphasis that are hovered, focused, or active. */
  --wpds-color-stroke-interactive-brand-active: #2337c8;
  /* Accessible stroke color used for interactive brand-toned elements with normal emphasis, in their disabled state. */
  --wpds-color-stroke-interactive-brand-disabled: #dbdbdb;
  /* Accessible stroke color used for interactive error-toned elements with normal emphasis. */
  --wpds-color-stroke-interactive-error: #cc1818;
  /* Accessible stroke color used for interactive error-toned elements with normal emphasis that are hovered, focused, or active. */
  --wpds-color-stroke-interactive-error-active: #9d0000;
  /* Accessible stroke color used for interactive error-toned elements with normal emphasis, in their disabled state. */
  --wpds-color-stroke-interactive-error-disabled: #dbdbdb;
  /* Accessible stroke color used for interactive error-toned elements with strong emphasis. */
  --wpds-color-stroke-interactive-error-strong: #cc1818;
  /* Accessible stroke color applied to focus rings. */
  --wpds-color-stroke-focus: #3858e9;
  /* Cursor style for interactive controls that are not links (e.g. buttons, checkboxes, and toggles). */
  --wpds-cursor-control: pointer;
  /* Extra small padding */
  --wpds-dimension-padding-xs: 4px;
  /* Small padding */
  --wpds-dimension-padding-sm: 8px;
  /* Medium padding */
  --wpds-dimension-padding-md: 12px;
  /* Large padding */
  --wpds-dimension-padding-lg: 16px;
  /* Extra large padding */
  --wpds-dimension-padding-xl: 20px;
  /* 2x extra large padding */
  --wpds-dimension-padding-2xl: 24px;
  /* 3x extra large padding */
  --wpds-dimension-padding-3xl: 32px;
  /* Extra small gap */
  --wpds-dimension-gap-xs: 4px;
  /* Small gap */
  --wpds-dimension-gap-sm: 8px;
  /* Medium gap */
  --wpds-dimension-gap-md: 12px;
  /* Large gap */
  --wpds-dimension-gap-lg: 16px;
  /* Extra large gap */
  --wpds-dimension-gap-xl: 24px;
  /* 2x extra large gap */
  --wpds-dimension-gap-2xl: 32px;
  /* 3x extra large gap */
  --wpds-dimension-gap-3xl: 40px;
  /* Notification indicators */
  --wpds-dimension-size-5xs: 4px;
  /* Visual size for small interactive elements like resize handles */
  --wpds-dimension-size-4xs: 8px;
  /* Small markers */
  --wpds-dimension-size-3xs: 12px;
  /* For small controls like checkboxes and radios, or small decorative icons */
  --wpds-dimension-size-2xs: 16px;
  /* For medium sized icons */
  --wpds-dimension-size-xs: 20px;
  /* For icons and small buttons */
  --wpds-dimension-size-sm: 24px;
  /* For medium-sized buttons and inputs */
  --wpds-dimension-size-md: 32px;
  /* Default size for buttons and inputs */
  --wpds-dimension-size-lg: 40px;
  /* Extra small surface width */
  --wpds-dimension-surface-width-xs: 240px;
  /* Small surface width */
  --wpds-dimension-surface-width-sm: 320px;
  /* Medium surface width */
  --wpds-dimension-surface-width-md: 400px;
  /* Large surface width */
  --wpds-dimension-surface-width-lg: 560px;
  /* Extra large surface width */
  --wpds-dimension-surface-width-xl: 720px;
  /* 2x extra large surface width */
  --wpds-dimension-surface-width-2xl: 960px;
  /* Micro-delays and transition offsets */
  --wpds-motion-duration-xs: 50ms;
  /* Micro-interactions like focus rings and state changes */
  --wpds-motion-duration-sm: 100ms;
  /* Standard transitions like menus and popovers */
  --wpds-motion-duration-md: 200ms;
  /* Deliberate animations like slides and reveals */
  --wpds-motion-duration-lg: 300ms;
  /* Extended animations like complex or multi-step transitions */
  --wpds-motion-duration-xl: 400ms;
  /* Nearly imperceptible easing for hover, color, and background transitions */
  --wpds-motion-easing-subtle: cubic-bezier( 0.15, 0, 0.15, 1 );
  /* General-purpose easing for on-screen movement like resizing, morphing, and layout shifts */
  --wpds-motion-easing-balanced: cubic-bezier( 0.4, 0, 0.2, 1 );
  /* Noticeable easing for enter/exit and spatial transitions like menus, popovers, dialogs, and drawers */
  --wpds-motion-easing-expressive: cubic-bezier( 0.25, 0, 0, 1 );
  /* Headings font family */
  --wpds-typography-font-family-heading: -apple-system, system-ui, 'Segoe UI',
  	'Roboto', 'Oxygen-Sans', 'Ubuntu', 'Cantarell', 'Helvetica Neue',
  	sans-serif;
  /* Body font family */
  --wpds-typography-font-family-body: -apple-system, system-ui, 'Segoe UI',
  	'Roboto', 'Oxygen-Sans', 'Ubuntu', 'Cantarell', 'Helvetica Neue',
  	sans-serif;
  /* Monospace font family */
  --wpds-typography-font-family-mono: 'Menlo', 'Consolas', monaco, monospace;
  /* Extra small font size */
  --wpds-typography-font-size-xs: 11px;
  /* Small font size */
  --wpds-typography-font-size-sm: 12px;
  /* Medium font size */
  --wpds-typography-font-size-md: 13px;
  /* Large font size */
  --wpds-typography-font-size-lg: 15px;
  /* Extra large font size */
  --wpds-typography-font-size-xl: 20px;
  /* 2X large font size */
  --wpds-typography-font-size-2xl: 32px;
  /* Extra small line height */
  --wpds-typography-line-height-xs: 16px;
  /* Small line height */
  --wpds-typography-line-height-sm: 20px;
  /* Medium line height */
  --wpds-typography-line-height-md: 24px;
  /* Large line height */
  --wpds-typography-line-height-lg: 28px;
  /* Extra large line height */
  --wpds-typography-line-height-xl: 32px;
  /* 2X large line height */
  --wpds-typography-line-height-2xl: 40px;
  /* Baseline text weight for body copy and UI text */
  --wpds-typography-font-weight-default: 400;
  /* Elevated text weight for labels, controls, and headings */
  --wpds-typography-font-weight-emphasis: 600;
}

@media (min-resolution: 192dpi) {
  :root {
    /* Border width for focus ring */
    --wpds-border-width-focus: 1.5px;
  }
}
[data-wpds-corner-radius=none],
:root[data-wpds-root-provider=true][data-wpds-corner-radius=none] {
  /* Buttons and other elements nested inside controls. */
  --wpds-border-radius-xs: 0px;
  /* Standalone buttons, inputs, and compact controls. */
  --wpds-border-radius-sm: 0px;
  /* Menus, popovers, and other small portaled overlays. */
  --wpds-border-radius-md: 0px;
  /* Cards, dialogs, notices, and other larger content containers. */
  --wpds-border-radius-lg: 0px;
  /* Page and app shell surfaces. */
  --wpds-border-radius-xl: 0px;
}

[data-wpds-corner-radius=subtle],
:root[data-wpds-root-provider=true][data-wpds-corner-radius=subtle] {
  /* Buttons and other elements nested inside controls. */
  --wpds-border-radius-xs: 1px;
  /* Standalone buttons, inputs, and compact controls. */
  --wpds-border-radius-sm: 2px;
  /* Menus, popovers, and other small portaled overlays. */
  --wpds-border-radius-md: 4px;
  /* Cards, dialogs, notices, and other larger content containers. */
  --wpds-border-radius-lg: 8px;
  /* Page and app shell surfaces. */
  --wpds-border-radius-xl: 12px;
}

[data-wpds-corner-radius=moderate],
:root[data-wpds-root-provider=true][data-wpds-corner-radius=moderate] {
  /* Buttons and other elements nested inside controls. */
  --wpds-border-radius-xs: 6px;
  /* Standalone buttons, inputs, and compact controls. */
  --wpds-border-radius-sm: 8px;
  /* Menus, popovers, and other small portaled overlays. */
  --wpds-border-radius-md: 12px;
  /* Cards, dialogs, notices, and other larger content containers. */
  --wpds-border-radius-lg: 16px;
  /* Page and app shell surfaces. */
  --wpds-border-radius-xl: 20px;
}

[data-wpds-corner-radius=pronounced],
:root[data-wpds-root-provider=true][data-wpds-corner-radius=pronounced] {
  /* Buttons and other elements nested inside controls. */
  --wpds-border-radius-xs: 18px;
  /* Standalone buttons, inputs, and compact controls. */
  --wpds-border-radius-sm: 20px;
  /* Menus, popovers, and other small portaled overlays. */
  --wpds-border-radius-md: 22px;
  /* Cards, dialogs, notices, and other larger content containers. */
  --wpds-border-radius-lg: 24px;
  /* Page and app shell surfaces. */
  --wpds-border-radius-xl: 26px;
}