.wp-block-comments-pagination > .wp-block-comments-pagination-next,
.wp-block-comments-pagination > .wp-block-comments-pagination-previous,
.wp-block-comments-pagination > .wp-block-comments-pagination-numbers {
  font-size: inherit;
}
.wp-block-comments-pagination .wp-block-comments-pagination-previous-arrow {
  margin-right: 1ch;
  display: inline-block;
}
.wp-block-comments-pagination .wp-block-comments-pagination-previous-arrow:not(.is-arrow-chevron) {
  transform: scaleX(1) /*rtl:scaleX(-1);*/;
}
.wp-block-comments-pagination .wp-block-comments-pagination-next-arrow {
  margin-left: 1ch;
  display: inline-block;
}
.wp-block-comments-pagination .wp-block-comments-pagination-next-arrow:not(.is-arrow-chevron) {
  transform: scaleX(1) /*rtl:scaleX(-1);*/;
}
.wp-block-comments-pagination.aligncenter {
  justify-content: center;
}