<?php
/**
 * Script module registry - Auto-generated by build process.
 * Do not edit this file manually.
 *
 * @package wp
 */

return array(
	array(
		'id' => '@wordpress/a11y',
		'path' => 'a11y/index',
		'asset' => 'a11y/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/abilities',
		'path' => 'abilities/index',
		'asset' => 'abilities/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-editor/utils/fit-text-frontend',
		'path' => 'block-editor/utils/fit-text-frontend',
		'asset' => 'block-editor/utils/fit-text-frontend.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/accordion/view',
		'path' => 'block-library/accordion/view',
		'asset' => 'block-library/accordion/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/file/view',
		'path' => 'block-library/file/view',
		'asset' => 'block-library/file/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/form/view',
		'path' => 'block-library/form/view',
		'asset' => 'block-library/form/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/image/view',
		'path' => 'block-library/image/view',
		'asset' => 'block-library/image/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/navigation/view',
		'path' => 'block-library/navigation/view',
		'asset' => 'block-library/navigation/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/playlist/view',
		'path' => 'block-library/playlist/view',
		'asset' => 'block-library/playlist/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/query/view',
		'path' => 'block-library/query/view',
		'asset' => 'block-library/query/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/search/view',
		'path' => 'block-library/search/view',
		'asset' => 'block-library/search/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/block-library/tabs/view',
		'path' => 'block-library/tabs/view',
		'asset' => 'block-library/tabs/view.min.asset.php',
	),
	array(
		'id' => '@wordpress/boot',
		'path' => 'boot/index',
		'asset' => 'boot/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/connectors',
		'path' => 'connectors/index',
		'asset' => 'connectors/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/content-types',
		'path' => 'content-types/index',
		'asset' => 'content-types/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/core-abilities',
		'path' => 'core-abilities/index',
		'asset' => 'core-abilities/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/dashboard-init',
		'path' => 'dashboard-init/index',
		'asset' => 'dashboard-init/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/edit-site-init',
		'path' => 'edit-site-init/index',
		'asset' => 'edit-site-init/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/interactivity',
		'path' => 'interactivity/index',
		'asset' => 'interactivity/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/interactivity-router',
		'path' => 'interactivity-router/index',
		'asset' => 'interactivity-router/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/interactivity-router/full-page',
		'path' => 'interactivity-router/full-page',
		'asset' => 'interactivity-router/full-page.min.asset.php',
	),
	array(
		'id' => '@wordpress/latex-to-mathml',
		'path' => 'latex-to-mathml/index',
		'asset' => 'latex-to-mathml/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/latex-to-mathml/loader',
		'path' => 'latex-to-mathml/loader',
		'asset' => 'latex-to-mathml/loader.min.asset.php',
	),
	array(
		'id' => '@wordpress/lazy-editor',
		'path' => 'lazy-editor/index',
		'asset' => 'lazy-editor/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/route',
		'path' => 'route/index',
		'asset' => 'route/index.min.asset.php',
	),
	array(
		'id' => '@wordpress/video-conversion/loader',
		'path' => 'video-conversion/loader',
		'asset' => 'video-conversion/loader.min.asset.php',
	),
	array(
		'id' => '@wordpress/video-conversion/worker',
		'path' => 'video-conversion/worker',
		'asset' => 'video-conversion/worker.min.asset.php',
		'min_only' => true,
	),
	array(
		'id' => '@wordpress/vips/loader',
		'path' => 'vips/loader',
		'asset' => 'vips/loader.min.asset.php',
	),
	array(
		'id' => '@wordpress/vips/worker',
		'path' => 'vips/worker',
		'asset' => 'vips/worker.min.asset.php',
		'min_only' => true,
	),
	array(
		'id' => '@wordpress/workflow',
		'path' => 'workflow/index',
		'asset' => 'workflow/index.min.asset.php',
	),
);
