/**
 * Typography
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
 * Breakpoints & Media Queries
 */
/**
*  Converts a hex value into the rgb equivalent.
*
* @param {string} hex - the hexadecimal value to convert
* @return {string} comma separated rgb values
*/
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Breakpoint mixins
 */
/**
 * Focus styles.
 */
/**
 * Standard focus rings for the WordPress Design System.
 *
 * Apply `outset-ring__focus` inside the relevant pseudo-class at the call site,
 * e.g. `&:focus { @include outset-ring__focus(); }`.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
/**
 * Creates a checkerboard pattern background to indicate transparency.
 * @param {String} $size - The size of the squares in the checkerboard pattern. Default is 12px.
 */
body.admin-color-light {
  --wp-admin-theme-color: #007cba;
  --wp-admin-theme-color--rgb: 0, 124, 186;
  --wp-admin-theme-color-darker-10: rgb(0, 107, 160.5);
  --wp-admin-theme-color-darker-10--rgb: 0, 107, 160.5;
  --wp-admin-theme-color-darker-20: #005a87;
  --wp-admin-theme-color-darker-20--rgb: 0, 90, 135;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  body.admin-color-light {
    --wp-admin-border-width-focus: 1.5px;
  }
}

body.admin-color-modern {
  --wp-admin-theme-color: #3858e9;
  --wp-admin-theme-color--rgb: 56, 88, 233;
  --wp-admin-theme-color-darker-10: rgb(33.0384615385, 68.7307692308, 230.4615384615);
  --wp-admin-theme-color-darker-10--rgb: 33.0384615385, 68.7307692308, 230.4615384615;
  --wp-admin-theme-color-darker-20: rgb(23.6923076923, 58.1538461538, 214.3076923077);
  --wp-admin-theme-color-darker-20--rgb: 23.6923076923, 58.1538461538, 214.3076923077;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  body.admin-color-modern {
    --wp-admin-border-width-focus: 1.5px;
  }
}

body.admin-color-blue {
  --wp-admin-theme-color: #437aa8;
  --wp-admin-theme-color--rgb: 67, 122, 168;
  --wp-admin-theme-color-darker-10: rgb(59.729787234, 108.7617021277, 149.770212766);
  --wp-admin-theme-color-darker-10--rgb: 59.729787234, 108.7617021277, 149.770212766;
  --wp-admin-theme-color-darker-20: rgb(52.4595744681, 95.5234042553, 131.5404255319);
  --wp-admin-theme-color-darker-20--rgb: 52.4595744681, 95.5234042553, 131.5404255319;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  body.admin-color-blue {
    --wp-admin-border-width-focus: 1.5px;
  }
}

body.admin-color-coffee {
  --wp-admin-theme-color: #916745;
  --wp-admin-theme-color--rgb: 145, 103, 69;
  --wp-admin-theme-color-darker-10: rgb(127.7219626168, 90.726635514, 60.7780373832);
  --wp-admin-theme-color-darker-10--rgb: 127.7219626168, 90.726635514, 60.7780373832;
  --wp-admin-theme-color-darker-20: rgb(110.4439252336, 78.453271028, 52.5560747664);
  --wp-admin-theme-color-darker-20--rgb: 110.4439252336, 78.453271028, 52.5560747664;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  body.admin-color-coffee {
    --wp-admin-border-width-focus: 1.5px;
  }
}

body.admin-color-ectoplasm {
  --wp-admin-theme-color: #646c3e;
  --wp-admin-theme-color--rgb: 100, 108, 62;
  --wp-admin-theme-color-darker-10: rgb(85, 91.8, 52.7);
  --wp-admin-theme-color-darker-10--rgb: 85, 91.8, 52.7;
  --wp-admin-theme-color-darker-20: rgb(70, 75.6, 43.4);
  --wp-admin-theme-color-darker-20--rgb: 70, 75.6, 43.4;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  body.admin-color-ectoplasm {
    --wp-admin-border-width-focus: 1.5px;
  }
}

body.admin-color-midnight {
  --wp-admin-theme-color: #cf4339;
  --wp-admin-theme-color--rgb: 207, 67, 57;
  --wp-admin-theme-color-darker-10: rgb(191.9634146341, 56.2317073171, 46.5365853659);
  --wp-admin-theme-color-darker-10--rgb: 191.9634146341, 56.2317073171, 46.5365853659;
  --wp-admin-theme-color-darker-20: rgb(171.4390243902, 50.2195121951, 41.5609756098);
  --wp-admin-theme-color-darker-20--rgb: 171.4390243902, 50.2195121951, 41.5609756098;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  body.admin-color-midnight {
    --wp-admin-border-width-focus: 1.5px;
  }
}

body.admin-color-ocean {
  --wp-admin-theme-color: #567958;
  --wp-admin-theme-color--rgb: 86, 121, 88;
  --wp-admin-theme-color-darker-10: rgb(75.4057971014, 106.0942028986, 77.1594202899);
  --wp-admin-theme-color-darker-10--rgb: 75.4057971014, 106.0942028986, 77.1594202899;
  --wp-admin-theme-color-darker-20: rgb(64.8115942029, 91.1884057971, 66.3188405797);
  --wp-admin-theme-color-darker-20--rgb: 64.8115942029, 91.1884057971, 66.3188405797;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  body.admin-color-ocean {
    --wp-admin-border-width-focus: 1.5px;
  }
}

body.admin-color-sunrise {
  --wp-admin-theme-color: #ad631e;
  --wp-admin-theme-color--rgb: 173, 99, 30;
  --wp-admin-theme-color-darker-10: rgb(151.2684729064, 86.5640394089, 26.2315270936);
  --wp-admin-theme-color-darker-10--rgb: 151.2684729064, 86.5640394089, 26.2315270936;
  --wp-admin-theme-color-darker-20: rgb(129.5369458128, 74.1280788177, 22.4630541872);
  --wp-admin-theme-color-darker-20--rgb: 129.5369458128, 74.1280788177, 22.4630541872;
  --wp-admin-border-width-focus: 2px;
}
@media (min-resolution: 192dpi) {
  body.admin-color-sunrise {
    --wp-admin-border-width-focus: 1.5px;
  }
}