.wp-block-playlist-track:has([aria-current=true]) {
  background-color: color-mix(in srgb, currentColor 10%, transparent);
}
.wp-block-playlist-track:hover {
  background-color: color-mix(in srgb, currentColor 15%, transparent);
}
.wp-block-playlist__tracklist-show-numbers .wp-block-playlist-track {
  counter-increment: playlist-track;
}
.wp-block-playlist-track .wp-block-playlist-track__button {
  display: flex;
  align-items: center;
  width: 100%;
  padding: var(--wp--preset--spacing--20, 0.5em);
  font-size: inherit;
  font-family: inherit;
  text-align: right;
  background-color: transparent;
  color: inherit;
  border: 0;
  outline-offset: 2px;
  cursor: pointer;
}
.wp-block-playlist__tracklist-show-numbers .wp-block-playlist-track .wp-block-playlist-track__button::before {
  content: counter(playlist-track);
  width: 2ch;
  margin-left: var(--wp--preset--spacing--20, 0.5em);
  font-size: 0.85em;
  opacity: 0.7;
}
.wp-block-playlist-track .wp-block-playlist-track__button .wp-block-playlist-track__image {
  flex: 0 0 50px;
  width: 50px;
  height: 50px;
  margin-left: var(--wp--preset--spacing--20, 0.5em);
  border: 1px solid rgba(0, 0, 0, 0.08);
  box-sizing: border-box;
  -o-object-fit: cover;
     object-fit: cover;
}
.wp-block-playlist-track .wp-block-playlist-track__button .wp-block-playlist-track__content {
  flex: 1 1 0;
  min-width: 0;
}
.wp-block-playlist-track .wp-block-playlist-track__button .wp-block-playlist-track__title {
  display: block;
}
.wp-block-playlist-track .wp-block-playlist-track__button .wp-block-playlist-track__artist {
  display: block;
  font-size: 0.85em;
  opacity: 0.7;
  margin-top: 0.125em;
}
.wp-block-playlist-track .wp-block-playlist-track__button .wp-block-playlist-track__length {
  margin-right: auto;
  font-size: 0.85em;
  opacity: 0.7;
}