.wp-block-read-more {
  display: block;
  width: -moz-fit-content;
  width: fit-content;
}
.wp-block-read-more:where(:not([style*=text-decoration])) {
  text-decoration: none;
}
.wp-block-read-more:where(:not([style*=text-decoration])):focus, .wp-block-read-more:where(:not([style*=text-decoration])):active {
  text-decoration: none;
}