.wp-block-comment-template {
  box-sizing: border-box;
  margin-bottom: 0;
  max-width: 100%;
  list-style: none;
  padding: 0;
}
.wp-block-comment-template li {
  clear: both;
}
.wp-block-comment-template ol {
  margin-bottom: 0;
  max-width: 100%;
  list-style: none;
  padding-left: 2rem;
}
.wp-block-comment-template.alignleft {
  float: left;
}
.wp-block-comment-template.aligncenter {
  margin-left: auto;
  margin-right: auto;
  width: -moz-fit-content;
  width: fit-content;
}
.wp-block-comment-template.alignright {
  float: right;
}