<?php
/**
 * Title: Shop homepage
 * Slug: twentytwentyfive/page-shop-home
 * Categories: twentytwentyfive_page
 * Keywords: starter
 * Block Types: core/post-content
 * Post Types: page, wp_template
 * Viewport width: 1400
 * Description: A shop homepage pattern.
 *
 * @package WordPress
 * @subpackage Twenty_Twenty_Five
 * @since Twenty Twenty-Five 1.0
 */

?>

<!-- wp:pattern {"slug":"twentytwentyfive/banner-intro-image"} /-->
<!-- wp:pattern {"slug":"twentytwentyfive/grid-with-categories"} /-->
<!-- wp:pattern {"slug":"twentytwentyfive/media-instagram-grid"} /-->
