(function() {
"use strict";
var wp;
(wp ||= {}).htmlEntities = (() => {
  var __defProp = Object.defineProperty;
  var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
  var __getOwnPropNames = Object.getOwnPropertyNames;
  var __hasOwnProp = Object.prototype.hasOwnProperty;
  var __export = (target, all) => {
    for (var name in all)
      __defProp(target, name, { get: all[name], enumerable: true });
  };
  var __copyProps = (to, from, except, desc) => {
    if (from && typeof from === "object" || typeof from === "function") {
      for (let key of __getOwnPropNames(from))
        if (!__hasOwnProp.call(to, key) && key !== except)
          __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
    }
    return to;
  };
  var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

  // packages/html-entities/build-module/index.mjs
  var index_exports = {};
  __export(index_exports, {
    decodeEntities: () => decodeEntities
  });
  var _decodeTextArea;
  function decodeEntities(html) {
    if ("string" !== typeof html || -1 === html.indexOf("&")) {
      return html;
    }
    if (void 0 === _decodeTextArea) {
      if (document.implementation && document.implementation.createHTMLDocument) {
        _decodeTextArea = document.implementation.createHTMLDocument("").createElement("textarea");
      } else {
        _decodeTextArea = document.createElement("textarea");
      }
    }
    _decodeTextArea.innerHTML = html;
    const decoded = _decodeTextArea.textContent ?? "";
    _decodeTextArea.innerHTML = "";
    return decoded;
  }
  return __toCommonJS(index_exports);
})();
(window.wp ||= {}).htmlEntities = wp.htmlEntities;
})();
