<?php
/**
 * Plugin constants - Auto-generated by build process.
 * Do not edit this file manually.
 *
 * Returns an array of constants for use in other templates.
 *
 * @package wp
 */

return array(
	'version' => '23.6.0-rc.1',
	'build_url' => includes_url( 'build/' ),
);
