$highlight-color: #437aa8;

@use "../_admin.scss" with (
	$scheme-name: "blue",
	$base-color: #245278,
	$icon-color: #e5f8ff,
	$highlight-color: $highlight-color,
	$notification-color: #e1a948,
	$menu-highlight-text: #fff,
	$menu-highlight-icon: #fff,
	$menu-bubble-text: #1e1e1e,
	$menu-submenu-text: #e2ecf1,
	$menu-submenu-focus-text: #fff,

	$dashboard-icon-background: $highlight-color
);
